@@ -1,5 +1,5 @@
 package XML::Grammar::Fiction::FromProto;
-$XML::Grammar::Fiction::FromProto::VERSION = '0.22.3';
+$XML::Grammar::Fiction::FromProto::VERSION = '0.22.4';
 use strict;
 use warnings;
 use autodie;
@@ -15,19 +15,14 @@ my $fiction_ns =
 
 
 
-my %lookup = ( map { $_ => $_ } qw( li ol ul ) );
+my %lookup = ( map { $_ => +{ tag => $_, wrap_para => 0, }, } qw( li ol ul ) );
 
 around '_calc_passthrough_cb' => sub {
     my $orig   = shift;
     my $self   = shift;
     my ($name) = @_;
 
-    if ( $lookup{$name} )
-    {
-        return +{ tag => $name, wrap_para => 0, };
-    }
-
-    return $orig->( $self, @_ );
+    return ( $lookup{$name} // $orig->( $self, @_ ) );
 };
 
 sub _output_tag_with_childs_and_common_attributes
@@ -321,7 +316,7 @@ on failure.
 
 =head1 VERSION
 
-version 0.22.3
+version 0.22.4
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
