@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
-$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.22.3';
+$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.22.4';
 use strict;
 use warnings;
 
@@ -98,8 +98,9 @@ sub _flush_buffer
 }
 
 my %passthrough_elem = (
-    b => sub { return shift->_bold_tag_name(); },
-    i => sub { return shift->_italics_tag_name(); },
+    b => sub { return +{ tag => shift->_bold_tag_name(), wrap_para => 1, }; },
+    i =>
+        sub { return +{ tag => shift->_italics_tag_name(), wrap_para => 1, }; },
 );
 
 sub _calc_passthrough_cb
@@ -165,8 +166,6 @@ sub _write_Element_Paragraph
             }
         )
     );
-
-    # ( $self->_writer->within_element( $self->_paragraph_tag ) )
 }
 
 sub _write_Element_Element
@@ -282,10 +281,6 @@ sub _write_Element_elem
         defined( my $out_name = $self->_calc_passthrough_name( $name, $elem ) )
         )
     {
-        if ( "" eq ref $out_name )
-        {
-            $out_name = { tag => $out_name, wrap_para => 1, };
-        }
         my $out_cb = sub {
             return $self->_output_tag_with_childs(
                 {
@@ -485,7 +480,7 @@ Internal - (to settle pod-coverage.).
 
 =head1 VERSION
 
-version 0.22.3
+version 0.22.4
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
