@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto::Parser::QnD;
-$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.22.3';
+$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.22.4';
 use strict;
 use warnings;
 
@@ -27,6 +27,21 @@ before 'next_line_ref' => sub {
     return;
 };
 
+sub _debug
+{
+    my ( $self, $args ) = @_;
+
+    if (1)
+    {
+        my $name = $args->{name};
+        cluck "${name}[[["
+            . join( ",", map { $_->name() } @{ $self->_tags_stack } ) . "; "
+            . ${ $self->curr_line_ref } . "]]]";
+    }
+
+    return;
+}
+
 sub _top_is_para
 {
     my $self = shift;
@@ -418,14 +433,6 @@ sub _process_closed_para
 sub _close_para
 {
     my $self = shift;
-    if (0)
-    {
-        warn "_close_para[[["
-            . join( ",", map { $_->name() } @{ $self->_tags_stack } ) . "; "
-            . ${ $self->curr_line_ref } . "]]]";
-
-        # body...
-    }
 
     my $open = $self->_pop_tag();
 
@@ -454,25 +461,9 @@ sub _create_start_para
 sub _start_para
 {
     my $self = shift;
-    if (0)
-    {
-        warn "start---_start_para[[["
-            . join( ",", map { $_->name() } @{ $self->_tags_stack } ) . "; "
-            . ${ $self->curr_line_ref } . "]]]";
-
-        # body...
-    }
     $self->_push_tag( $self->_create_start_para() );
 
     $self->_in_para(1);
-    if (0)
-    {
-        warn "_start_para[[["
-            . join( ",", map { $_->name() } @{ $self->_tags_stack } ) . "; "
-            . ${ $self->curr_line_ref } . "]]]";
-
-        # body...
-    }
 
     return;
 }
@@ -565,14 +556,6 @@ before '_handle_open_tag' => sub {
         }
     }
 
-    if (0)
-    {
-        cluck "_handle_open_tag[[["
-            . join( ",", map { $_->name() } @{ $self->_tags_stack } ) . "; "
-            . ${ $self->curr_line_ref } . "]]]";
-
-        # body...
-    }
     return;
 };
 
@@ -651,7 +634,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.22.3
+version 0.22.4
 
 =head1 METHODS
 
